@@ -16,10 +16,9 @@ namespace depthmapX {
 
     class Polyline : public QtRegion {
       public:
-        std::vector<Point2f> m_vertices;
-        bool m_closed = false;
-        Polyline(std::vector<Point2f> vertices, bool closed)
-            : m_vertices(vertices), m_closed(closed) {}
+        std::vector<Point2f> vertices;
+        bool closed = false;
+        Polyline(std::vector<Point2f> vertices, bool closed) : vertices(vertices), closed(closed) {}
     };
 
     enum ImportType { DRAWINGMAP, DATAMAP };
